@@ -91,7 +91,7 @@ namespace PropertyTest
         const int p6;
         std::string p7_impl; std::string* p7;
         MyEnum p8_impl; const MyEnum* p8;
-        boost::shared_ptr<MyType> p9;
+        std::shared_ptr<MyType> p9;
 
         // ***** member functions *****
         bool p10; bool getP10() {return p10;}
